@@ -20,7 +20,7 @@
 #include <QQueue>
 #include <QTimer>
 #include <QElapsedTimer>
-#include <QNetworkConfigurationManager>
+#include <QNetworkInformation>
 
 #include "qtsingleapplication.h"
 
@@ -49,12 +49,6 @@ class Folder;
 class ShellExtensionsServer;
 class SslErrorDialog;
 
-#ifdef Q_OS_MACOS
-namespace Mac {
-class FileProvider;
-}
-#endif
-
 /**
  * @brief The Application class
  * @ingroup gui
@@ -102,15 +96,15 @@ signals:
     void folderRemoved();
     void folderStateChanged(OCC::Folder *);
     void isShowingSettingsDialog();
+    void systemPaletteChanged();
 
 protected slots:
     void slotParseMessage(const QString &, QObject *);
     void slotCheckConnection();
-    void slotUseMonoIconsChanged(bool);
     void slotCleanup();
     void slotAccountStateAdded(OCC::AccountState *accountState);
     void slotAccountStateRemoved(OCC::AccountState *accountState);
-    void slotSystemOnlineConfigurationChanged(QNetworkConfiguration);
+    void slotSystemOnlineConfigurationChanged();
     void slotGuiIsShowingSettings();
 
 private:
@@ -119,7 +113,7 @@ private:
     void handleEditLocallyFromOptions();
 
     AccountManager::AccountsRestoreResult restoreLegacyAccount();
-    void setupConfigFile();
+    bool setupConfigFolderFromLegacyLocation(const QString &legacyLocation) const;
     void setupAccountsAndFolders();
 
     /**
@@ -152,7 +146,6 @@ private:
 
     ClientProxy _proxy;
 
-    QNetworkConfigurationManager _networkConfigurationManager;
     QTimer _checkConnectionTimer;
 
     QString _overrideServerUrl;
@@ -164,8 +157,6 @@ private:
     QScopedPointer<FolderMan> _folderManager;
 #if defined(Q_OS_WIN)
     QScopedPointer<ShellExtensionsServer> _shellExtensionsServer;
-#elif defined(Q_OS_MACOS)
-    QScopedPointer<Mac::FileProvider> _fileProvider;
 #endif
 };
 
