@@ -107,8 +107,6 @@ Folder::Folder(const FolderDefinition &definition,
 
     connect(_engine.data(), &SyncEngine::aboutToRemoveAllFiles,
         this, &Folder::slotAboutToRemoveAllFiles);
-    connect(_engine.data(), &SyncEngine::aboutToRemoveRemnantsReadOnlyFolders,
-            this, &Folder::slotNeedToRemoveRemnantsReadOnlyFolders);
     connect(_engine.data(), &SyncEngine::transmissionProgress, this, &Folder::slotTransmissionProgress);
     connect(_engine.data(), &SyncEngine::itemCompleted,
         this, &Folder::slotItemCompleted);
@@ -144,7 +142,7 @@ Folder::Folder(const FolderDefinition &definition,
     });
 
     // Potentially upgrade suffix vfs to windows vfs
-    ENFORCE(_vfs);
+    Q_ASSERT(_vfs);
     if (_definition.virtualFilesMode == Vfs::WithSuffix
         && _definition.upgradeVfsMode) {
         if (isVfsPluginAvailable(Vfs::WindowsCfApi)) {
@@ -515,8 +513,8 @@ void Folder::createGuiLog(const QString &filename, LogStatus status, int count,
 
 void Folder::startVfs()
 {
-    ENFORCE(_vfs);
-    ENFORCE(_vfs->mode() == _definition.virtualFilesMode);
+    Q_ASSERT(_vfs);
+    Q_ASSERT(_vfs->mode() == _definition.virtualFilesMode);
 
     const auto result = Vfs::checkAvailability(path(), _vfs->mode());
     if (!result) {
@@ -654,8 +652,11 @@ void Folder::slotWatchedPathChanged(const QStringView &path, const ChangeReason
         if (record.isValid()
             && !FileSystem::fileChanged(path.toString(), record._fileSize, record._modtime) && _vfs) {
             spurious = true;
-
             if (auto pinState = _vfs->pinState(relativePath.toString())) {
+                qCDebug(lcFolder) << "PinState for" << relativePath << "is" << *pinState;
+                if (*pinState == PinState::Unspecified) {
+                    spurious = false;
+                }
                 if (*pinState == PinState::AlwaysLocal && record.isVirtualFile()) {
                     spurious = false;
                 }
@@ -1723,36 +1724,6 @@ void Folder::slotAboutToRemoveAllFiles(SyncFileItem::Direction dir, std::functio
     msgBox->open();
 }
 
-void Folder::slotNeedToRemoveRemnantsReadOnlyFolders(const QList<SyncFileItemPtr> &folders,
-                                                     const QString &localPath,
-                                                     std::function<void (bool)> callback)
-{
-    auto listOfFolders = QStringList{};
-    for (const auto &oneFolder : folders) {
-        listOfFolders.push_back(oneFolder->_file);
-    }
-
-    qCInfo(lcFolder()) << "will delete invalid read-only folders:" << listOfFolders.join(", ");
-
-    setSyncPaused(true);
-    for(const auto &oneFolder : folders) {
-#if !defined(Q_OS_MACOS) || __MAC_OS_X_VERSION_MIN_REQUIRED >= MAC_OS_X_VERSION_10_15
-        const auto fileInfo = QFileInfo{localPath + oneFolder->_file};
-        const auto parentFolderPath = fileInfo.dir().absolutePath();
-        const auto parentPermissionsHandler = FileSystem::FilePermissionsRestore{parentFolderPath, FileSystem::FolderPermissions::ReadWrite};
-#endif
-        if (oneFolder->_type == ItemType::ItemTypeDirectory) {
-            FileSystem::removeRecursively(localPath + oneFolder->_file);
-        } else {
-            FileSystem::remove(localPath + oneFolder->_file);
-        }
-    }
-    callback(true);
-    setSyncPaused(false);
-    _lastEtag.clear();
-    slotScheduleThisFolder();
-}
-
 void Folder::removeLocalE2eFiles()
 {
     qCDebug(lcFolder) << "Removing local E2EE files";
