@@ -336,10 +336,6 @@ public slots:
     // connected to the corresponding signals in the SyncEngine
     void slotAboutToRemoveAllFiles(OCC::SyncFileItem::Direction, std::function<void(bool)> callback);
 
-    void slotNeedToRemoveRemnantsReadOnlyFolders(const QList<SyncFileItemPtr> &folders,
-                                                 const QString &localPath,
-                                                 std::function<void(bool)> callback);
-
     /**
       * Starts a sync operation
       *
