@@ -47,14 +47,14 @@ private slots:
     void slotSocketDestroyed(const QObject * const object);
     void slotReadyRead();
 
-    void slotAccountStateChanged(const OCC::AccountState::State state);
+    void slotAccountStateChanged(const OCC::AccountState::State state) const;
 
     void parseReceivedLine(const QString &receivedLine);
     void requestFileProviderDomainInfo() const;
     void sendAccountDetails() const;
     void sendNotAuthenticated() const;
 
-    void reportSyncState(const QString &receivedState);
+    void reportSyncState(const QString &receivedState) const;
 
 private:
     QPointer<QLocalSocket> _socket;
