@@ -34,12 +34,12 @@ class ProxyAuthDialog : public QDialog
 
 public:
     explicit ProxyAuthDialog(QWidget *parent = nullptr);
-    ~ProxyAuthDialog();
+    ~ProxyAuthDialog() override;
 
     void setProxyAddress(const QString &address);
 
-    QString username() const;
-    QString password() const;
+    [[nodiscard]] QString username() const;
+    [[nodiscard]] QString password() const;
 
     /// Resets the dialog for new credential entry.
     void reset();
