@@ -41,6 +41,11 @@ public:
 private slots:
     void initTestCase()
     {
+        OCC::Logger::instance()->setLogFlush(true);
+        OCC::Logger::instance()->setLogDebug(true);
+
+        QStandardPaths::setTestModeEnabled(true);
+
         OCC::ClientStatusReportingNetwork::clientStatusReportingTrySendTimerInterval = 1000;
         OCC::ClientStatusReportingNetwork::repordSendIntervalMs = 2000;
 
